@@ -18,6 +18,7 @@ from motus.rutas_distancias import distancias as m_dist, rutas_vectoriales as m_
 from motus.graficador import cilindros as m_ci
 from motus.regiones_cuadriculadas import regiones_cuadriculadas as m_reg_cuad,\
     regiones_preferidas as m_reg_pref, matrices_recurrencia as m_recurr
+from motus.regresion_lineal import analisis_regresion_lineal as m_arl
 import motus.graficador.config_graficas as m_cg
 
 
@@ -43,6 +44,7 @@ class Experimento:
 
         self.entropias = dict()
         self.histogramas = dict()
+        self.regresiones_lineales = dict()
 
         nombre_recortado = pathlib.Path(self.nombre_archivo)
         try:
@@ -142,6 +144,7 @@ class Experimento:
         self.posiciones_y = arreglo_posicion_y
 
         self.config_graficas = m_cg.ConfigGrafica()
+        self.procesador_reg_lineal = m_arl.ProcesamientoRegresionLineal()
         self.rutas_vectoriales = m_rv.InformacionRutasVectoriales(posiciones_eje_x=self.posiciones_x,
                                                                   posiciones_eje_y=self.posiciones_y)
 
@@ -414,7 +417,6 @@ class Experimento:
     def genera_modulo_para_reducir_sesiones(self):
 
         cantidad_filas = self.cantidad_filas
-
         cantidad_columnas = self.cantidad_columnas
 
         tamanio_horizontal = self.dimension_caja[0] / cantidad_columnas
@@ -727,54 +729,14 @@ class Experimento:
 
         elif nombre_grafica == 'ruta_vectoriales_consecuencia':
 
-            brinco_temporal, tamanio_vectores, consecuencia_elegida = \
-                config_grafica.regresa_config_grafica_consecuencias()
+            posiciones_x, posiciones_y, direcciones_x, direcciones_y = \
+                self.rutas_vectoriales.regresa_posiciones_direcciones()
 
-            x_pos_antes_consecuencia = self.posiciones_x.tolist()
-            y_pos_antes_consecuencia = self.posiciones_y.tolist()
+            x_pos_antes_consecuencia, x_pos_despues_consecuencia = posiciones_x
+            y_pos_antes_consecuencia, y_pos_despues_consecuencia = posiciones_y
 
-            x_pos_despues_consecuencia = self.posiciones_x.tolist()
-            y_pos_despues_consecuencia = self.posiciones_y.tolist()
-
-            x_pos_antes_consecuencia = x_pos_antes_consecuencia[int(consecuencia_elegida - tamanio_vectores):
-                                                                int(consecuencia_elegida):
-                                                                int(brinco_temporal)]
-
-            y_pos_antes_consecuencia = y_pos_antes_consecuencia[int(consecuencia_elegida - tamanio_vectores):
-                                                                int(consecuencia_elegida):
-                                                                int(brinco_temporal)]
-
-            x_pos_despues_consecuencia = x_pos_despues_consecuencia[int(consecuencia_elegida):
-                                                                    int(consecuencia_elegida + tamanio_vectores):
-                                                                    int(brinco_temporal)]
-            y_pos_despues_consecuencia = y_pos_despues_consecuencia[int(consecuencia_elegida):
-                                                                    int(consecuencia_elegida + tamanio_vectores):
-                                                                    int(brinco_temporal)]
-
-            new_x_pos_antes = x_pos_antes_consecuencia.copy()
-            new_x_pos_antes.append(self.posiciones_x[consecuencia_elegida])
-            new_y_pos_antes = y_pos_antes_consecuencia.copy()
-            new_y_pos_antes.append(self.posiciones_y[consecuencia_elegida])
-
-            x_direct_antes, y_direct_antes = m_rv.obtener_vectores_posicion_flechas(new_x_pos_antes,
-                                                                                    new_y_pos_antes)
-
-            print("x_pos_antes_consecuencia: ", x_pos_antes_consecuencia)
-            print("y_pos_antes_consecuencia: ", y_pos_antes_consecuencia)
-
-            print("x_direct_antes: ", x_direct_antes)
-            print("y_direct_antes: ", y_direct_antes)
-
-            x_direct_despues, y_direct_despues = m_rv.obtener_vectores_posicion_flechas(x_pos_despues_consecuencia,
-                                                                                        y_pos_despues_consecuencia)
-
-            print("-----------------------------------------------------------")
-
-            print("x_pos_despues_consecuencia: ", x_pos_despues_consecuencia)
-            print("y_pos_antes_consecuencia: ", y_pos_despues_consecuencia)
-
-            print("x_direct_despues: ", x_direct_despues)
-            print("y_direct_despues: ", y_direct_despues)
+            x_direct_antes, x_direct_despues = direcciones_x
+            y_direct_antes, y_direct_despues = direcciones_y
 
             plt.quiver(x_pos_antes_consecuencia, y_pos_antes_consecuencia,
                        x_direct_antes, y_direct_antes,
