@@ -2,49 +2,13 @@ import numpy as np
 import pandas as pd
 
 
-def obtener_valor_promediado_para_distancia_a_objeto(arreglo, indice, tamanio_intervalo):
-    if indice - tamanio_intervalo < 0:
-        left = arreglo[0:indice]
-    else:
-        left = arreglo[(indice - tamanio_intervalo):indice]
-    if indice + tamanio_intervalo > len(arreglo):
-        right = arreglo[(indice + 1):len(arreglo)]
-    else:
-        right = arreglo[indice + 1:(indice + tamanio_intervalo) + 1]
-    arreglo_final = left + [arreglo[indice]] + right
-    promedio = sum(arreglo_final) / len(arreglo_final)
-    return promedio
-
-
-def obtener_arreglo_con_valores_promediados_para_distancia_a_objeto(arreglo, tamanio_intervalo):
-    arreglo_con_promedio = []
-    for i in range(len(arreglo)):
-        valor_promediado = obtener_valor_promediado_para_distancia_a_objeto(arreglo, i, tamanio_intervalo)
-        arreglo_con_promedio.append(valor_promediado)
-    return arreglo_con_promedio
-
-
-def obtener_vectores_posicion_flechas(vector_x, vector_y):
-    x_direct = []
-    y_direct = []
-
-    for i in range(0, len(vector_x) - 1):
-        x1 = vector_x[i]
-        x2 = vector_x[i + 1]
-        y1 = vector_y[i]
-        y2 = vector_y[i + 1]
-        x_punta, y_punta = obtener_punta_vector(x1, x2, y1, y2)
-        x_direct.append(x_punta)
-        y_direct.append(y_punta)
-
-    return x_direct, y_direct
 
 
 
 
 
-def obtener_punta_vector(x_1, x_2, y_1, y_2):
-    return x_2 - x_1, y_2 - y_1
+
+
 
 
 def pintar_cilindro(x_centro, y_centro, radio, altura, ax):
