@@ -27,10 +27,7 @@ class ConfigGrafica:
         self.brinco_temporal_consecuencias = 1
         self.tamanio_vectores_consecuencias = 1
 
-        self.resultados_regresion_lineal = None
-        self.indices_tiempo = None
-        self.series_tiempo = None
-        self.pendientes_regresion_lineal = None
+        self.regresion_lineal_seleccionada = None
 
         self.regiones_preferidas_3d = [0]
 
@@ -52,9 +49,7 @@ class ConfigGrafica:
         return self.dist_max_figuras, self.total_figuras, self.tipo_figura, self.rot_grafica_3d
 
     def regresa_config_grafica_regresion_lineal(self):
-        return self.resultados_regresion_lineal,\
-               self.indices_tiempo,\
-               self.series_tiempo
+        return self.regresion_lineal_seleccionada
 
     def regresa_config_grafica_consecuencias(self):
         return self.brinco_temporal_consecuencias,\
